@@ -856,17 +856,24 @@ task_activated_cb (GtkTreeView       *view,
                    GtkTreeViewColumn *column,
                    ClockData         *cd)
 {
-        GtkTreeIter iter;
-        char       *uri;
+        GtkTreeIter  iter;
+        GtkTreePath *child_path;
+        char        *uri;
 
-        gtk_tree_model_get_iter (GTK_TREE_MODEL (cd->tasks_model), &iter, path);
+        child_path = gtk_tree_model_filter_convert_path_to_child_path (cd->tasks_filter, path);
+
+        gtk_tree_model_get_iter (GTK_TREE_MODEL (cd->tasks_model), &iter, child_path);
         gtk_tree_model_get (GTK_TREE_MODEL (cd->tasks_model), &iter,
                             TASK_COLUMN_URL, &uri, -1);
 
-        if (uri)
+        if (uri) {
                 gnome_url_show_on_screen (uri,
 					  gtk_widget_get_screen (cd->applet),
 					  NULL);
+        }
+
+        g_free (uri);
+        gtk_tree_path_free (child_path);
 
         return TRUE;
 }
@@ -924,10 +931,10 @@ appointment_pixbuf_cell_data_func (GtkTreeViewColumn *column,
 }
 
 static int
-compare_priority  (GtkTreeModel *model,
-                   GtkTreeIter  *a,
-                   GtkTreeIter  *b,
-                   gpointer      user_data)
+compare_tasks  (GtkTreeModel *model,
+                GtkTreeIter  *a,
+                GtkTreeIter  *b,
+                gpointer      user_data)
 {
         int priority_a;
         int priority_b;
@@ -946,8 +953,21 @@ compare_priority  (GtkTreeModel *model,
 		return -1;
 	else if (priority_a > priority_b)
 		return 1;
-	else
-		return 0;
+	else {
+                GTime due_time_a, due_time_b;
+
+                gtk_tree_model_get (model, a, TASK_COLUMN_DUE_TIME,
+                                    &due_time_a, G_MAXINT32);
+                gtk_tree_model_get (model, b, TASK_COLUMN_DUE_TIME,
+                                    &due_time_b, G_MAXINT32);
+
+                if (due_time_a < due_time_b)
+                        return -1;
+                else if (due_time_a > due_time_b)
+                        return 1;
+                else
+                        return 0;
+        }
 }
 
 static GtkWidget *
@@ -993,7 +1013,7 @@ create_task_list (ClockData  *cd,
 
                 gtk_tree_sortable_set_sort_func (GTK_TREE_SORTABLE (cd->tasks_model),
                                                  TASK_COLUMN_PRIORITY,
-                                                 compare_priority,
+                                                 compare_tasks,
                                                  NULL, NULL);
 
                 gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (cd->tasks_model),
@@ -1698,41 +1718,6 @@ applet_change_orient (PanelApplet       *applet,
         update_popup (cd);
 }
 
-static void
-applet_change_background (PanelApplet               *applet,
-			  PanelAppletBackgroundType  type,
-			  GdkColor                  *color,
-			  GdkPixmap                 *pixmap,
-			  ClockData                 *cd)
-{
-	GtkRcStyle *rc_style;
-	GtkStyle   *style;
-
-	/* reset style */
-	gtk_widget_set_style (GTK_WIDGET (cd->applet), NULL);
-	rc_style = gtk_rc_style_new ();
-	gtk_widget_modify_style (GTK_WIDGET (cd->applet), rc_style);
-	gtk_rc_style_unref (rc_style);
-
-	switch (type) {
-	case PANEL_NO_BACKGROUND:
-		break;
-	case PANEL_COLOR_BACKGROUND:
-		gtk_widget_modify_bg (GTK_WIDGET (cd->applet),
-				      GTK_STATE_NORMAL, color);
-		break;
-	case PANEL_PIXMAP_BACKGROUND:
-		style = gtk_style_copy (GTK_WIDGET (cd->applet)->style);
-		if (style->bg_pixmap[GTK_STATE_NORMAL])
-			g_object_unref (style->bg_pixmap[GTK_STATE_NORMAL]);
-		style->bg_pixmap[GTK_STATE_NORMAL] = g_object_ref (pixmap);
-		gtk_widget_set_style (GTK_WIDGET (cd->applet), style);
-		g_object_unref (style);
-		break;
-	}
-}
-
-
 /* this is when the panel size changes */
 static void
 applet_change_pixel_size (PanelApplet *applet,
@@ -2289,10 +2274,8 @@ fill_clock_applet (PanelApplet *applet)
 			  G_CALLBACK (applet_change_pixel_size),
 			  cd);
 
-	g_signal_connect (G_OBJECT (cd->applet),
-			  "change_background",
-			  G_CALLBACK (applet_change_background),
-			  cd);
+	panel_applet_set_background_widget (PANEL_APPLET (cd->applet),
+					    GTK_WIDGET (cd->applet));
 
 	panel_applet_setup_menu_from_file (PANEL_APPLET (cd->applet),
 					   NULL,
