@@ -1,4 +1,5 @@
-/*
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
+ *
  * panel-action-button.c: panel "Action Button" module
  *
  * Copyright (C) 2002 Sun Microsystems, Inc.
@@ -72,7 +73,8 @@ static GConfEnumStringPair panel_action_type_map [] = {
 	{ PANEL_ACTION_SEARCH,         "search"         },
 	{ PANEL_ACTION_SCREENSHOT,     "screenshot"     },
 	{ PANEL_ACTION_FORCE_QUIT,     "force-quit"     },
-	{ PANEL_ACTION_CONNECT_SERVER, "connect-server" }
+	{ PANEL_ACTION_CONNECT_SERVER, "connect-server" },
+	{ 0,                           NULL             },
 };
 
 /* Lock Screen
@@ -90,13 +92,22 @@ screensaver_properties_enabled (void)
 	    panel_lockdown_get_disable_lock_screen ())
 		return FALSE;
 
-	return TRUE;
+	return panel_lock_screen_action_available ("prefs");
 }
 
 static gboolean
 screensaver_enabled (void)
 {
-  return !panel_lockdown_get_disable_lock_screen ();
+	if (panel_lockdown_get_disable_lock_screen ())
+		return FALSE;
+
+	return panel_lock_screen_action_available ("lock");
+}
+
+static gboolean
+panel_action_lock_is_disabled (void)
+{
+	return !screensaver_enabled ();
 }
 
 static void
@@ -128,7 +139,7 @@ panel_action_lock_setup_menu (PanelActionButton *button)
 
 	panel_applet_add_callback (button->priv->info,
 				   "prefs",
-				   NULL,
+				   GTK_STOCK_PROPERTIES,
 				   _("_Properties"),
 				   screensaver_properties_enabled);
 }
@@ -137,24 +148,11 @@ static void
 panel_action_lock_invoke_menu (PanelActionButton *button,
 			       const char *callback_name)
 {
-	char *command = NULL;
+	g_return_if_fail (PANEL_IS_ACTION_BUTTON (button));
+	g_return_if_fail (callback_name != NULL);
 
-	if (!strcmp (callback_name, "prefs"))
-		command = g_strdup ("xscreensaver-demo");
-
-	else if (!strcmp (callback_name, "activate") ||
-		 !strcmp (callback_name, "lock") ||
-		 !strcmp (callback_name, "exit") ||
-		 !strcmp (callback_name, "restart"))
-		command = g_strdup_printf ("xscreensaver-command -%s", callback_name);
-
-	if (command)
-		gdk_spawn_command_line_on_screen (
-			gtk_widget_get_screen (GTK_WIDGET (button)),
-			command,
-			NULL);
-
-	g_free (command);
+	panel_lock_screen_action (gtk_widget_get_screen (GTK_WIDGET (button)),
+				  callback_name);
 }
 
 /* Log Out
@@ -205,11 +203,12 @@ panel_action_search (GtkWidget *widget)
 		}
 		if (error) {
 			panel_error_dialog (screen,
-			                    "cannot_exec_gnome-search-tool", TRUE,
-			                    _("Cannot execute '%s'"),
-			                    "%s",
-			                    "gnome-search-tool",
-			                    error->message);
+					    "cannot_exec_gnome-search-tool",
+					    TRUE,
+					    _("Could not execute '%s'"),
+					    "%s",
+					    "gnome-search-tool",
+					    error->message);
 			g_error_free (error);
 		}
 		g_free (file);
@@ -217,9 +216,9 @@ panel_action_search (GtkWidget *widget)
 	else if (!gdk_spawn_on_screen (screen, NULL, argv, NULL,
 				  G_SPAWN_SEARCH_PATH,
 				  NULL, NULL, NULL, &error)) {
-		panel_error_dialog (screen,
+				  panel_error_dialog (screen,
 				    "cannot_exec_gnome-search-tool", TRUE,
-				    _("Cannot execute '%s'"),
+				    _("Could not execute '%s'"),
 				    "%s",
 				    "gnome-search-tool",
 				    error->message);
@@ -243,7 +242,7 @@ panel_action_screenshot (GtkWidget *widget)
 				  NULL, NULL, NULL, &error)) {
 		panel_error_dialog (screen,
 				    "cannot_exec_gnome-screenshot", TRUE,
-				    _("Cannot execute '%s'"),
+				    _("Could not execute '%s'"),
 				    "%s",
 				    "gnome-screenshot",
 				    error->message);
@@ -279,8 +278,9 @@ panel_action_connect_server (GtkWidget *widget)
 		error_dialog = panel_error_dialog (screen,
 						   "cannot_connect_server",
 						   TRUE,
-						   _("Cannot connect to server"),
-						   "%s", error->message);
+						   _("Could not connect to server"),
+						   "%s",
+						   error->message);
 		g_clear_error (&error);
 	}
 }
@@ -317,7 +317,7 @@ static PanelAction actions [] = {
 		panel_action_lock_screen,
 		panel_action_lock_setup_menu,
 		panel_action_lock_invoke_menu,
-		panel_lockdown_get_disable_lock_screen
+		panel_action_lock_is_disabled
 	},
 	{
 		PANEL_ACTION_LOGOUT,
@@ -917,11 +917,9 @@ panel_action_button_set_dnd_enabled (PanelActionButton *button,
 		gtk_drag_source_set (GTK_WIDGET (button), GDK_BUTTON1_MASK,
 				     dnd_targets, 1,
 				     GDK_ACTION_COPY | GDK_ACTION_MOVE);
-		/* FIXME: waiting for bug #116577
 		if (actions [button->priv->type].icon_name != NULL)
-		gtk_drag_source_set_icon_name (GTK_WIDGET (button),
-						actions [button->priv->type].icon_name);
-						*/
+			gtk_drag_source_set_icon_name (GTK_WIDGET (button),
+						       actions [button->priv->type].icon_name);
 		GTK_WIDGET_SET_FLAGS (button, GTK_NO_WINDOW);
 	} else
 		gtk_drag_source_unset (GTK_WIDGET (button));
