@@ -50,7 +50,7 @@ panel_context_menu_show_help (GtkWidget *w,
 			      gpointer data)
 {
 	panel_show_help (gtk_widget_get_screen (w),
-			 "user-guide.xml", "gospanel-5");
+			 "user-guide.xml", "gospanel-1");
 }
 
 static gboolean
@@ -163,8 +163,8 @@ panel_context_menu_remove_panel (GtkWidget *menuitem,
 	if (panel_toplevel_is_last_unattached (toplevel)) {
 		panel_error_dialog (menuitem_to_screen (menuitem),
 				    "cannot_remove_last_panel", TRUE,
-				    _("You cannot remove your last panel."),
-				    NULL);
+				    _("Cannot delete this panel"),
+				    _("You must always have at least one panel."));
 		return;
 	}
 
@@ -184,9 +184,9 @@ panel_context_menu_setup_remove_panel_item (GtkWidget *menu,
 	g_assert (PANEL_IS_TOPLEVEL (panel_widget->toplevel));
 
 	sensitive =
-		panel_toplevel_is_last_unattached (panel_widget->toplevel) ||
-		!panel_lockdown_get_locked_down () ||
-		!panel_profile_id_lists_are_writable ();
+		!panel_toplevel_is_last_unattached (panel_widget->toplevel) &&
+		!panel_lockdown_get_locked_down () &&
+		panel_profile_id_lists_are_writable ();
 
 	gtk_widget_set_sensitive (menuitem, sensitive);
 
@@ -240,7 +240,19 @@ make_panel_submenu (PanelWidget *panel_widget,
 		gtk_widget_set_sensitive (menuitem, FALSE);
 
 	menuitem = gtk_image_menu_item_new ();
+	setup_menuitem (menuitem,
+			GTK_ICON_SIZE_MENU,
+			gtk_image_new_from_stock (GTK_STOCK_PROPERTIES,
+						  GTK_ICON_SIZE_MENU),
+			_("_Properties"),
+			FALSE);
 
+	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
+	g_signal_connect_swapped (menuitem, "activate",
+				  G_CALLBACK (panel_properties_dialog_present), 
+				  panel_widget->toplevel);
+
+	menuitem = gtk_image_menu_item_new ();
 	setup_menuitem (menuitem, 
 			GTK_ICON_SIZE_MENU,
 			gtk_image_new_from_stock (GTK_STOCK_DELETE,
@@ -255,19 +267,6 @@ make_panel_submenu (PanelWidget *panel_widget,
 			  G_CALLBACK (panel_context_menu_setup_remove_panel_item),
 			  menuitem);
 
-	menuitem = gtk_image_menu_item_new ();
-	setup_menuitem (menuitem,
-			GTK_ICON_SIZE_MENU,
-			gtk_image_new_from_stock (GTK_STOCK_PROPERTIES,
-						  GTK_ICON_SIZE_MENU),
-			_("_Properties"),
-			FALSE);
-
-	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
-	g_signal_connect_swapped (menuitem, "activate",
-				  G_CALLBACK (panel_properties_dialog_present), 
-				  panel_widget->toplevel);
-
 	add_menu_separator (menu);
 
 	menuitem = gtk_image_menu_item_new ();
@@ -296,7 +295,6 @@ panel_context_menu_create (PanelWidget *panel)
 	if (panel->master_widget) {
 		gpointer    *pointer;
 		AppletInfo  *info;
-		PanelWidget *parent_panel;
 
 		pointer = g_object_get_data (G_OBJECT (panel->master_widget),
 					     "applet_info");
@@ -305,7 +303,6 @@ panel_context_menu_create (PanelWidget *panel)
 		info = (AppletInfo *) pointer;
 
 		if (info->menu == NULL) {
-			parent_panel = PANEL_WIDGET (info->widget->parent);
 			info->menu = panel_applet_create_menu (info);
 		}
 
